@@ -98,6 +98,34 @@ class TestServer(unittest.TestCase):
         self.assertTrue('client_id' in data)
         self.assertTrue('conversion' in data)
         self.assertTrue('value' in data['conversion'])
+        self.assertTrue('kpi' in data['conversion'])
+        self.assertEqual(data['conversion']['kpi'], None)
+
+    def test_convert_with_kpi(self):
+        self.client.get("/participate?experiment=dummy-kpi&client_id=foo&alternatives=one&alternatives=two")
+        resp = self.client.get("/convert?experiment=dummy-kpi&client_id=foo&kpi=alligator")
+        data = json.loads(resp.data)
+        self.assertEqual(200, resp.status_code)
+        self.assertTrue('status' in data)
+        self.assertEqual(data['status'], 'ok')
+        self.assertTrue('alternative' in data)
+        self.assertTrue('name' in data['alternative'])
+        self.assertTrue('experiment' in data)
+        self.assertTrue('name' in data['experiment'])
+        self.assertTrue('client_id' in data)
+        self.assertTrue('conversion' in data)
+        self.assertTrue('value' in data['conversion'])
+        self.assertTrue('kpi' in data['conversion'])
+        self.assertEqual(data['conversion']['kpi'], 'alligator')
+
+    def test_convert_bad_kpi_failure(self):
+        self.client.get("/participate?experiment=dummy-kpi&client_id=foo&alternatives=one&alternatives=two")
+        resp = self.client.get("/convert?experiment=dummy-kpi&client_id=foo&kpi=&&^^!*(")
+        data = json.loads(resp.data)
+        self.assertEqual(400, resp.status_code)
+        self.assertTrue('status' in data)
+        self.assertEqual(data['message'], 'invalid kpi name')
+        self.assertEqual(data['status'], 'failed')
 
     def test_convert_fail(self):
         resp = self.client.get("/convert?experiment=baz&client_id=bar")
